@@ -1,5 +1,5 @@
 /* 
-Copyright (C) 2000-2012 Matteo Fasiolo  matteo.fasiolo@gmail.com
+Copyright (C) 2014 Matteo Fasiolo  matteo.fasiolo@gmail.com
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -83,7 +83,7 @@ RcppExport SEXP rmvnCpp(SEXP n_,
       #endif
       
       sitmo::prng_engine engine( coreSeed );
-      std::normal_distribution<> normal(0.0, 1.0);
+      boost::normal_distribution<> normal(0.0, 1.0);
       
       // Filling "out" with standard normal rvs
       #ifdef SUPPORT_OPENMP
